A silver catalyst activated by stacking faults for the hydrogen evolution reaction | Nature Catalysis
Author: Zhe Li
Description: Finding highly active and low-cost catalysts is a crucial endeavour to harvest clean hydrogen via electrochemical water splitting. Currently, the best catalyst for the hydrogen evolution reaction is based on metallic platinum whose high price severely restricts large-scale application. Here we report a silver catalyst with superior activity and durability in an acid medium that outperforms commercial platinum on carbon, especially under high applied voltages. We adopt a physical technique—laser ablation in liquid—to generate a high density of stacking faults in silver nanoparticles. We find that the stacking faults can cause a low coordination number and high tensile strain, which jointly improve the adsorption energy and transform the non-active silver into a highly active catalyst. In light of the high activity, conductivity, durability and low price, the silver catalyst can serve as a promising alternative to commercial platinum on carbon for industrial application. To achieve large [cell cut: 1303 characters, first 1000 kept]
Keywords: Electrocatalysis
Date: 2019-10-14

Skip to main content

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

Advertisement

- Article
- Published: 14 October 2019

# A silver catalyst activated by stacking faults for the hydrogen evolution reaction

- Zhe Li1,
- Jian-Yu Fu1,
- Yi Feng1,
- Cun-Ku Dong1,
- Hui Liu
  1 &
- Xi-Wen Du
  ORCID: orcid.org/0000-0002-2811-147X1

Nature Catalysis volume 2, pages1107–1114(2019)Cite this article

- 7060 Accesses

- 20 Citations

- 5 Altmetric

- Metrics details

### Subjects

- Electrocatalysis
- Energy
- Heterogeneous catalysis

## Abstract

Finding highly active and low-cost catalysts is a crucial endeavour to harvest clean hydrogen via electrochemical water splitting. Currently, the best catalyst for the hydrogen evolution reaction is based on metallic platinum whose high price severely restricts large-scale application. Here we report a silver catalyst with superior activity and durability in an acid medium that outperforms commercial platinum on carbon, especially under high applied voltages. We adopt a physical technique—laser ablation in liquid—to generate a high density of stacking faults in silver nanoparticles. We find that the stacking faults can cause a low coordination number and high tensile strain, which jointly improve the adsorption energy and transform the non-active silver into a highly active catalyst. In light of the high activity, conductivity, durability and low price, the silver catalyst can serve as a promising alternative to commercial platinum on carbon for industrial application.

Access through your institution
Change institution
Buy or subscribe

## Access options

Subscribe to Journal

Get full journal access for 1 year

$99.00

only $8.25 per issue

Subscribe

All prices are NET prices.
VAT will be added later in the checkout.

Rent or Buy article

Get time limited or full article access on ReadCube.

from$8.99

Rent or Buy

All prices are NET prices.

Fig. 1: Preparation and characterization of L-Ag NPs.
Fig. 2: HER activity and durability in Ar-saturated 0.5 M H2SO4 aqueous electrolyte.
Fig. 3: Calculations on the CNs of L-Ag, S-Ag and T-Ag catalysts.
Fig. 4: Analysis of the tensile strain in L-Ag.
Fig. 5: Theoretical calculations for the effect of CN and tensile strain on the hydrogen adsorption Gibbs free energy.

## Data availability

The data that support the plots within this paper and other findings of this study are available from the corresponding author upon reasonable request.

## References

1. 1.

   Su, J. W. et al. Ruthenium-cobalt nanoalloys encapsulated in nitrogen-doped graphene as active electrocatalysts for producing hydrogen in alkaline media. Nat. Commun. 8, 14969 (2017).

   Article Google Scholar

2. 2.

   Lu, X. F., Yu, L. & Lou, X. W. Highly crystalline Ni-doped FeP/carbon hollow nanorods as all-pH efficient and durable hydrogen evolving electrocatalysts. Sci. Adv. 5, 6009 (2019).

   Article Google Scholar

3. 3.

   Zheng, Y., Jiao, Y., Jaroniec, M. & Qiao, S. Z. Advancing the electrochemistry of the hydrogen evolution reaction through combining experiment and theory. Angew. Chem. Int. Ed. 54, 52–65 (2015).

   CAS Article Google Scholar

4. 4.

   Jiao, Y., Zheng, Y., Jaroniec, M. & Qiao, S. Z. Design of electrocatalysts for oxygen- and hydrogen-involving energy conversion reactions. Chem. Soc. Rev. 44, 2060–2086 (2015).

   CAS Article Google Scholar

5. 5.

   Fan, X. B. et al. Controlled exfoliation of MoS2 crystals into trilayer nanosheets. J. Am. Chem. Soc. 138, 5143–5149 (2016).

   CAS Article Google Scholar

6. 6.

   Xia, Y. N. In my element: silver. Chem. Eur. J. 24, 1–2 (2018).

   Article Google Scholar

7. 7.

   Zhou, Y. et al. Oxygen reduction at very low overpotential on nanoporous Ag catalysts. Adv. Energy Mater. 5, 1500149 (2015).

   Article Google Scholar

8. 8.

   Uchida, T., Mogami, H., Yamakata, A., Sasaki, Y. & Osawa, M. Hydrogen evolution reaction catalyzed by proton-coupled redox cycle of 4,4’-bipyridine monolayer adsorbed on silver electrodes. J. Am. Chem. Soc. 130, 10862–10863 (2008).

   CAS Article Google Scholar

9. 9.

   Campbell, F. W., Belding, S. R., Baron, R., Xiao, L. & Compton, R. G. The hydrogen evolution reaction at silver nanoparticle array and a silver macroelectrode compared: changed electrode kinetics between the macro- and nanoscales. J. Phys. Chem. C. 113, 14852–14857 (2009).

   CAS Article Google Scholar

10. 10.

    Safavi, A., kazemi, S. H. & Kazemi, H. Electrocatalytic behaviors of silver-palladium nanoalloys modified carbon ionic liquid electrode towards hydrogen evolution reaction. Fuel 118, 156–162 (2014).

    CAS Article Google Scholar

11. 11.

    Khorshidi, A., Violet, J., Hashemi, J. & Peterson, A. A. How strain can break the scaling relations of catalysis. Nat. Catal. 1, 263–268 (2018).

    Article Google Scholar

12. 12.

    Calle-Vallejo, F. et al. Finding optimal surface sites on heterogeneous catalysts by counting nearest neighbors. Science 350, 185–189 (2015).

    CAS Article Google Scholar

13. 13.

    Zambelli, T., Wintterlin, J., Trost, J. & Ertl, G. Identification of the “active sites” of a surface-catalyzed reaction. Science 273, 1688–1699 (1996).

    CAS Article Google Scholar

14. 14.

    Nørskov, J. K., Bligaard, T., Rossmeisl, J. & Christensen, C. H. Towards the computational design of solid catalysts. Nat. Chem. 1, 37–46 (2009).

    Article Google Scholar

15. 15.

    Tedsree, K. et al. Hydrogen production from formic acid decomposition at room temperature using a Ag–Pd core–shell nanocatalyst. Nat. Nanotechnol. 6, 302–307 (2011).

    CAS Article Google Scholar

16. 16.

    Escudero-Escribano, M. et al. Pt5Gd as a highly active and stable catalyst for oxygen electroreduction. J. Am. Chem. Soc. 134, 16476–16479 (2012).

    CAS Article Google Scholar

17. 17.

    Wang, H. T. et al. Direct and continuous strain control of catalysts with tunable battery electrode materials. Science 354, 1031–1036 (2016).

    CAS Article Google Scholar

18. 18.

    Wang, L. et al. Tunable intrinsic strain in two-dimensional transition metal electrocatalysts. Science 363, 870–874 (2019).

    CAS Article Google Scholar

19. 19.

    Strasser, P. et al. Lattice-strain control of the activity in dealloyed core–shell fuel cell catalysts. Nat. Chem. 2, 454–460 (2010).

    CAS Article Google Scholar

20. 20.

    Escudero-Escribano, M. et al. Tuning the activity of Pt alloy electrocatalysts by means of the lanthanide contraction. Science 352, 73–76 (2016).

    CAS Article Google Scholar

21. 21.

    Edalati, K. & Horita, Z. J. High-pressure torsion of pure metals: Influence of atomic bond parameters and stacking fault energy on grain size and correlation with hardness. Acta Mater. 59, 6831–6836 (2011).

    CAS Article Google Scholar

22. 22.

    Qin, Y. C. et al. Microwave-assisted synthesis of multiply-twinned Au–Ag nanocrystals on reduced graphene oxide for high catalytic performance towards hydrogen evolution reaction. J. Mater. Chem. A 4, 3865 (2016).

    CAS Article Google Scholar

23. 23.

    Xia, X. H., Shen, X., Zhao, X. J., Ye, W. C. & Wang, C. M. Operando synthesis of a dendritic and well-crystallized molybdenum oxide/silver catalyst for enhanced activity in the hydrogen evolution reaction. ChemCatChem 7, 2517–2525 (2015).

    CAS Article Google Scholar

24. 24.

    Yin, J. et al. Ni–C–N nanosheets as catalyst for hydrogen evolution reaction. J. Am. Chem. Soc. 138, 14546–14549 (2016).

    CAS Article Google Scholar

25. 25.

    Deng, J. et al. Multiscale structural and electronic control of molybdenum disulfide foam for highly efficient hydrogen production. Nat. Commun. 8, 14430 (2017).

    CAS Article Google Scholar

26. 26.

    Kiritani, M. Story of stacking fault tetrahedra. Mater. Chem. Phys. 50, 133–138 (1997).

    CAS Article Google Scholar

27. 27.

    Cao, L. L. et al. Identification of single-atom active sites in carbon-based cobalt catalysts during electrocatalytic hydrogen evolution. Nat. Catal. 2, 134–141 (2019).

    CAS Article Google Scholar

28. 28.

    Jiao, J. Q. et al. Copper atom-pair catalyst anchored on alloy nanowires for selective and efficient electrochemical reduction of CO2. Nat. Chem. 11, 222–228 (2019).

    CAS Article Google Scholar

29. 29.

    Sun, Y. F. et al. Pits confined in ultrathin cerium (iv) oxide for studying catalytic centers in carbon monoxide oxidation. Nat. Commun. 4, 2899 (2013).

    Article Google Scholar

30. 30.

    Behafarid, F. et al. Structural and electronic properties of micellar Au nanoparticles: size and ligand effects. ACS Nano 8, 6671–6681 (2014).

    CAS Article Google Scholar

31. 31.

    Ling, T. et al. Activating cobalt (ii) oxide nanorods for efficient electrocatalysis by strain engineering. Nat. Commun. 8, 1509 (2017).

    Article Google Scholar

32. 32.

    Gan, L., Yu, R., Luo, J., Cheng, Z. Y. & Zhu, J. Lattice strain distributions in individual dealloyed Pt–Fe catalyst nanoparticles. J. Phys. Chem. Lett. 3, 934–938 (2012).

    CAS Article Google Scholar

33. 33.

    Jiao, Y., Zheng, Y., Davey, K. & Qiao, S. Z. Activity origin and catalyst design principles for electrocatalytic hydrogen evolution on heteroatom-doped graphene. Nat. Energy 1, 16130 (2016).

    CAS Article Google Scholar

34. 34.

    Wang, C. Q. et al. Creation of controllable high-density defects in silver nanowires for enhanced catalytic property. Nano Lett. 16, 5669–5674 (2016).

    CAS Article Google Scholar

35. 35.

    Zheng, Y. et al. High electrocatalytic hydrogen evolution activity of an anomalous ruthenium catalyst. J. Am. Chem. Soc. 138, 16174–16181 (2016).

    CAS Article Google Scholar

36. 36.

    Mahmood, J. et al. An efficient and pH-universal ruthenium-based catalyst for the hydrogen evolution reaction. Nat. Nanotechnol. 12, 441–446 (2017).

    CAS Article Google Scholar

37. 37.

    Banerjee, A., Dick, G. R., Yoshino, T. & Kanan, M. W. Carbon dioxide utilization via carbonate-promoted C–H carboxylation. Nature 531, 215–219 (2014).

    Article Google Scholar

Download references

## Acknowledgements

This work was supported in part by the Natural Science Foundation of China (grant nos. 51871160, 51671141, 51471115). The authors thank the BL14W1 beam line of the Shanghai Synchrotron Radiation Facility for synchrotron beam time and Y. L. Liang from Shanghai Institute of Applied Physics (Chinese Academy of Sciences) for XAS measurements. The authors thank R. C. Luo from the State Key Laboratory of Metal Matrix Composites (Shanghai Jiao Tong University) for TEM measurements.

## Author information

### Affiliations

1. Institute of New-Energy Materials, School of Materials Science and Engineering, Tianjin University, Tianjin, China

   Zhe Li, Jian-Yu Fu, Yi Feng, Cun-Ku Dong, Hui Liu & Xi-Wen Du

Authors

1. Zhe Li
   View author publications

   You can also search for this author in PubMed Google Scholar

2. Jian-Yu Fu
   View author publications

   You can also search for this author in PubMed Google Scholar

3. Yi Feng
   View author publications

   You can also search for this author in PubMed Google Scholar

4. Cun-Ku Dong
   View author publications

   You can also search for this author in PubMed Google Scholar

5. Hui Liu
   View author publications

   You can also search for this author in PubMed Google Scholar

6. Xi-Wen Du
   View author publications

   You can also search for this author in PubMed Google Scholar

### Contributions

X.-W.D. designed the project. Z.L. and Y.F. performed the experiment under the direction of X.-W.D. Z.L. and X.-WD. performed the experimental data analysis. J.-Y.F. and C.-K.D. performed the theoretical calculation. Z.L. and H.L. conducted the XAS test and analysed the data. Z.L. and X.-W.D. wrote the paper. All authors discussed the results and commented on the manuscript.

### Corresponding authors

Correspondence to Hui Liu or Xi-Wen Du.

## Ethics declarations

### Competing interests

The authors declare no competing interests.

## Additional information

Publisher’s note Springer Nature remains neutral with regard to jurisdictional claims in published maps and institutional affiliations.

## Supplementary information

Supplementary Figs. 1–54, Tables 1–3 and references.

### Supplementary Dataset 1

Atomic coordinates of the optimized computational models.

## Rights and permissions

Reprints and Permissions

## About this article

### Cite this article

Li, Z., Fu, JY., Feng, Y. et al. A silver catalyst activated by stacking faults for the hydrogen evolution reaction. Nat Catal 2, 1107–1114 (2019). https://doi.org/10.1038/s41929-019-0365-9

Download citation

- Received: 08 May 2019

- Accepted: 04 September 2019

- Published: 14 October 2019

- Issue Date: December 2019

- DOI: https://doi.org/10.1038/s41929-019-0365-9

## Further reading

- ### In-situ surface decoration of RuO2 nanoparticles by laser ablation for improved oxygen evolution reaction activity in both acid and alkali solutions

  - Zongpeng Wang
  - , Beibei Xiao
  - , Zhiping Lin
  - , Shijie Shen
  - , Aijiao Xu
  - , Zexin Du
  - , Yuchao Chen
  - & Wenwu Zhong

  Journal of Energy Chemistry (2021)

- ### Non-thermal radiation heating synthesis of nanomaterials

  - Guowei Xiong
  - , Jin Jia
  - , Lili Zhao
  - , Xiaoyan Liu
  - , Xiaoli Zhang
  - , Hong Liu
  - & Weijia Zhou

  Science Bulletin (2020)

- ### Well-defined FeP/CdS heterostructure construction with the assistance of amine for the efficient H2 evolution under visible light irradiation

  - Ming-Yu Dou
  - , Shu-Rui Han
  - , Xin-Xin Du
  - , Dong-Hui Pang
  - & Lei-Lei Li

  International Journal of Hydrogen Energy (2020)

- ### Light Tailoring of Internal Atomic Structure of Gold Nanorods

  - Jianfeng Yan
  - , Dezhi Zhu
  - , Jiawang Xie
  - , Yang Shao
  - & Wei Xiao

  Small (2020)

- ### Nonsolvent-induced phase separation-derived TiO2 nanotube arrays/porous Ti electrode as high-energy-density anode for lithium-ion batteries

  - Zhi-Jia Zhang
  - , Jun Zhao
  - , Zhi-Jun Qiao
  - , Jia-Min Wang
  - , Shi-Hao Sun
  - , Wen-Xing Fu
  - , Xi-Yuan Zhang
  - , Zhen-Yang Yu
  - , Yu-Hai Dou
  - , Jian-Li Kang
  - , Ding Yuan
  - , Yue-Zhan Feng
  - & Jian-Min Ma

  Rare Metals (2020)

Access through your institution
Change institution
Buy or subscribe

Sign up for the Nature Briefing newsletter — what matters in science, free to your inbox daily.

Email address
I agree my information will be processed in accordance with the Nature and Springer Nature Limited Privacy Policy.
Get the most important science stories of the day, free in your inbox. Sign up for Nature Briefing